@@ -6,14 +6,14 @@ Type annotations for shield service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_shield.type_defs import AttackDetailTypeDef
+    from mypy_boto3_shield.type_defs import AssociateDRTLogBucketRequestRequestTypeDef
 
-    data: AttackDetailTypeDef = {...}
+    data: AssociateDRTLogBucketRequestRequestTypeDef = {...}
     ```
 """
 import sys
 from datetime import datetime
-from typing import List
+from typing import Any, Dict, List
 
 from .literals import (
     AttackLayerType,
@@ -35,6 +35,10 @@ else:
 
 
 __all__ = (
+    "AssociateDRTLogBucketRequestRequestTypeDef",
+    "AssociateDRTRoleRequestRequestTypeDef",
+    "AssociateHealthCheckRequestRequestTypeDef",
+    "AssociateProactiveEngagementDetailsRequestRequestTypeDef",
     "AttackDetailTypeDef",
     "AttackPropertyTypeDef",
     "AttackStatisticsDataItemTypeDef",
@@ -43,21 +47,35 @@ __all__ = (
     "AttackVolumeStatisticsTypeDef",
     "AttackVolumeTypeDef",
     "ContributorTypeDef",
+    "CreateProtectionGroupRequestRequestTypeDef",
+    "CreateProtectionRequestRequestTypeDef",
     "CreateProtectionResponseTypeDef",
+    "DeleteProtectionGroupRequestRequestTypeDef",
+    "DeleteProtectionRequestRequestTypeDef",
+    "DescribeAttackRequestRequestTypeDef",
     "DescribeAttackResponseTypeDef",
     "DescribeAttackStatisticsResponseTypeDef",
     "DescribeDRTAccessResponseTypeDef",
     "DescribeEmergencyContactSettingsResponseTypeDef",
+    "DescribeProtectionGroupRequestRequestTypeDef",
     "DescribeProtectionGroupResponseTypeDef",
+    "DescribeProtectionRequestRequestTypeDef",
     "DescribeProtectionResponseTypeDef",
     "DescribeSubscriptionResponseTypeDef",
+    "DisassociateDRTLogBucketRequestRequestTypeDef",
+    "DisassociateHealthCheckRequestRequestTypeDef",
     "EmergencyContactTypeDef",
     "GetSubscriptionStateResponseTypeDef",
     "LimitTypeDef",
+    "ListAttacksRequestRequestTypeDef",
     "ListAttacksResponseTypeDef",
+    "ListProtectionGroupsRequestRequestTypeDef",
     "ListProtectionGroupsResponseTypeDef",
+    "ListProtectionsRequestRequestTypeDef",
     "ListProtectionsResponseTypeDef",
+    "ListResourcesInProtectionGroupRequestRequestTypeDef",
     "ListResourcesInProtectionGroupResponseTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "MitigationTypeDef",
     "PaginatorConfigTypeDef",
@@ -67,13 +85,48 @@ __all__ = (
     "ProtectionGroupTypeDef",
     "ProtectionLimitsTypeDef",
     "ProtectionTypeDef",
+    "ResponseMetadataTypeDef",
     "SubResourceSummaryTypeDef",
     "SubscriptionLimitsTypeDef",
     "SubscriptionTypeDef",
     "SummarizedAttackVectorTypeDef",
     "SummarizedCounterTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
     "TimeRangeTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateEmergencyContactSettingsRequestRequestTypeDef",
+    "UpdateProtectionGroupRequestRequestTypeDef",
+    "UpdateSubscriptionRequestRequestTypeDef",
+)
+
+AssociateDRTLogBucketRequestRequestTypeDef = TypedDict(
+    "AssociateDRTLogBucketRequestRequestTypeDef",
+    {
+        "LogBucket": str,
+    },
+)
+
+AssociateDRTRoleRequestRequestTypeDef = TypedDict(
+    "AssociateDRTRoleRequestRequestTypeDef",
+    {
+        "RoleArn": str,
+    },
+)
+
+AssociateHealthCheckRequestRequestTypeDef = TypedDict(
+    "AssociateHealthCheckRequestRequestTypeDef",
+    {
+        "ProtectionId": str,
+        "HealthCheckArn": str,
+    },
+)
+
+AssociateProactiveEngagementDetailsRequestRequestTypeDef = TypedDict(
+    "AssociateProactiveEngagementDetailsRequestRequestTypeDef",
+    {
+        "EmergencyContactList": List["EmergencyContactTypeDef"],
+    },
 )
 
 AttackDetailTypeDef = TypedDict(
@@ -169,20 +222,89 @@ ContributorTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredCreateProtectionGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateProtectionGroupRequestRequestTypeDef",
+    {
+        "ProtectionGroupId": str,
+        "Aggregation": ProtectionGroupAggregationType,
+        "Pattern": ProtectionGroupPatternType,
+    },
+)
+_OptionalCreateProtectionGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateProtectionGroupRequestRequestTypeDef",
+    {
+        "ResourceType": ProtectedResourceTypeType,
+        "Members": List[str],
+        "Tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateProtectionGroupRequestRequestTypeDef(
+    _RequiredCreateProtectionGroupRequestRequestTypeDef,
+    _OptionalCreateProtectionGroupRequestRequestTypeDef,
+):
+    pass
+
+
+_RequiredCreateProtectionRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateProtectionRequestRequestTypeDef",
+    {
+        "Name": str,
+        "ResourceArn": str,
+    },
+)
+_OptionalCreateProtectionRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateProtectionRequestRequestTypeDef",
+    {
+        "Tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateProtectionRequestRequestTypeDef(
+    _RequiredCreateProtectionRequestRequestTypeDef, _OptionalCreateProtectionRequestRequestTypeDef
+):
+    pass
+
+
 CreateProtectionResponseTypeDef = TypedDict(
     "CreateProtectionResponseTypeDef",
     {
         "ProtectionId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DeleteProtectionGroupRequestRequestTypeDef = TypedDict(
+    "DeleteProtectionGroupRequestRequestTypeDef",
+    {
+        "ProtectionGroupId": str,
+    },
+)
+
+DeleteProtectionRequestRequestTypeDef = TypedDict(
+    "DeleteProtectionRequestRequestTypeDef",
+    {
+        "ProtectionId": str,
+    },
+)
+
+DescribeAttackRequestRequestTypeDef = TypedDict(
+    "DescribeAttackRequestRequestTypeDef",
+    {
+        "AttackId": str,
     },
-    total=False,
 )
 
 DescribeAttackResponseTypeDef = TypedDict(
     "DescribeAttackResponseTypeDef",
     {
         "Attack": "AttackDetailTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 DescribeAttackStatisticsResponseTypeDef = TypedDict(
@@ -190,6 +312,7 @@ DescribeAttackStatisticsResponseTypeDef = TypedDict(
     {
         "TimeRange": "TimeRangeTypeDef",
         "DataItems": List["AttackStatisticsDataItemTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -198,39 +321,71 @@ DescribeDRTAccessResponseTypeDef = TypedDict(
     {
         "RoleArn": str,
         "LogBucketList": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 DescribeEmergencyContactSettingsResponseTypeDef = TypedDict(
     "DescribeEmergencyContactSettingsResponseTypeDef",
     {
         "EmergencyContactList": List["EmergencyContactTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeProtectionGroupRequestRequestTypeDef = TypedDict(
+    "DescribeProtectionGroupRequestRequestTypeDef",
+    {
+        "ProtectionGroupId": str,
     },
-    total=False,
 )
 
 DescribeProtectionGroupResponseTypeDef = TypedDict(
     "DescribeProtectionGroupResponseTypeDef",
     {
         "ProtectionGroup": "ProtectionGroupTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
+DescribeProtectionRequestRequestTypeDef = TypedDict(
+    "DescribeProtectionRequestRequestTypeDef",
+    {
+        "ProtectionId": str,
+        "ResourceArn": str,
+    },
+    total=False,
+)
+
 DescribeProtectionResponseTypeDef = TypedDict(
     "DescribeProtectionResponseTypeDef",
     {
         "Protection": "ProtectionTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 DescribeSubscriptionResponseTypeDef = TypedDict(
     "DescribeSubscriptionResponseTypeDef",
     {
         "Subscription": "SubscriptionTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DisassociateDRTLogBucketRequestRequestTypeDef = TypedDict(
+    "DisassociateDRTLogBucketRequestRequestTypeDef",
+    {
+        "LogBucket": str,
+    },
+)
+
+DisassociateHealthCheckRequestRequestTypeDef = TypedDict(
+    "DisassociateHealthCheckRequestRequestTypeDef",
+    {
+        "ProtectionId": str,
+        "HealthCheckArn": str,
     },
-    total=False,
 )
 
 _RequiredEmergencyContactTypeDef = TypedDict(
@@ -257,6 +412,7 @@ GetSubscriptionStateResponseTypeDef = TypedDict(
     "GetSubscriptionStateResponseTypeDef",
     {
         "SubscriptionState": SubscriptionStateType,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -269,73 +425,108 @@ LimitTypeDef = TypedDict(
     total=False,
 )
 
+ListAttacksRequestRequestTypeDef = TypedDict(
+    "ListAttacksRequestRequestTypeDef",
+    {
+        "ResourceArns": List[str],
+        "StartTime": "TimeRangeTypeDef",
+        "EndTime": "TimeRangeTypeDef",
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
 ListAttacksResponseTypeDef = TypedDict(
     "ListAttacksResponseTypeDef",
     {
         "AttackSummaries": List["AttackSummaryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-_RequiredListProtectionGroupsResponseTypeDef = TypedDict(
-    "_RequiredListProtectionGroupsResponseTypeDef",
-    {
-        "ProtectionGroups": List["ProtectionGroupTypeDef"],
-    },
-)
-_OptionalListProtectionGroupsResponseTypeDef = TypedDict(
-    "_OptionalListProtectionGroupsResponseTypeDef",
+ListProtectionGroupsRequestRequestTypeDef = TypedDict(
+    "ListProtectionGroupsRequestRequestTypeDef",
     {
         "NextToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
 
+ListProtectionGroupsResponseTypeDef = TypedDict(
+    "ListProtectionGroupsResponseTypeDef",
+    {
+        "ProtectionGroups": List["ProtectionGroupTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
 
-class ListProtectionGroupsResponseTypeDef(
-    _RequiredListProtectionGroupsResponseTypeDef, _OptionalListProtectionGroupsResponseTypeDef
-):
-    pass
-
+ListProtectionsRequestRequestTypeDef = TypedDict(
+    "ListProtectionsRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
 
 ListProtectionsResponseTypeDef = TypedDict(
     "ListProtectionsResponseTypeDef",
     {
         "Protections": List["ProtectionTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-_RequiredListResourcesInProtectionGroupResponseTypeDef = TypedDict(
-    "_RequiredListResourcesInProtectionGroupResponseTypeDef",
+_RequiredListResourcesInProtectionGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredListResourcesInProtectionGroupRequestRequestTypeDef",
     {
-        "ResourceArns": List[str],
+        "ProtectionGroupId": str,
     },
 )
-_OptionalListResourcesInProtectionGroupResponseTypeDef = TypedDict(
-    "_OptionalListResourcesInProtectionGroupResponseTypeDef",
+_OptionalListResourcesInProtectionGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalListResourcesInProtectionGroupRequestRequestTypeDef",
     {
         "NextToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
 
 
-class ListResourcesInProtectionGroupResponseTypeDef(
-    _RequiredListResourcesInProtectionGroupResponseTypeDef,
-    _OptionalListResourcesInProtectionGroupResponseTypeDef,
+class ListResourcesInProtectionGroupRequestRequestTypeDef(
+    _RequiredListResourcesInProtectionGroupRequestRequestTypeDef,
+    _OptionalListResourcesInProtectionGroupRequestRequestTypeDef,
 ):
     pass
 
 
+ListResourcesInProtectionGroupResponseTypeDef = TypedDict(
+    "ListResourcesInProtectionGroupResponseTypeDef",
+    {
+        "ResourceArns": List[str],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+    },
+)
+
 ListTagsForResourceResponseTypeDef = TypedDict(
     "ListTagsForResourceResponseTypeDef",
     {
         "Tags": List["TagTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 MitigationTypeDef = TypedDict(
@@ -420,6 +611,17 @@ ProtectionTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 SubResourceSummaryTypeDef = TypedDict(
     "SubResourceSummaryTypeDef",
     {
@@ -498,6 +700,14 @@ SummarizedCounterTypeDef = TypedDict(
     total=False,
 )
 
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "Tags": List["TagTypeDef"],
+    },
+)
+
 TagTypeDef = TypedDict(
     "TagTypeDef",
     {
@@ -515,3 +725,52 @@ TimeRangeTypeDef = TypedDict(
     },
     total=False,
 )
+
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "TagKeys": List[str],
+    },
+)
+
+UpdateEmergencyContactSettingsRequestRequestTypeDef = TypedDict(
+    "UpdateEmergencyContactSettingsRequestRequestTypeDef",
+    {
+        "EmergencyContactList": List["EmergencyContactTypeDef"],
+    },
+    total=False,
+)
+
+_RequiredUpdateProtectionGroupRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateProtectionGroupRequestRequestTypeDef",
+    {
+        "ProtectionGroupId": str,
+        "Aggregation": ProtectionGroupAggregationType,
+        "Pattern": ProtectionGroupPatternType,
+    },
+)
+_OptionalUpdateProtectionGroupRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateProtectionGroupRequestRequestTypeDef",
+    {
+        "ResourceType": ProtectedResourceTypeType,
+        "Members": List[str],
+    },
+    total=False,
+)
+
+
+class UpdateProtectionGroupRequestRequestTypeDef(
+    _RequiredUpdateProtectionGroupRequestRequestTypeDef,
+    _OptionalUpdateProtectionGroupRequestRequestTypeDef,
+):
+    pass
+
+
+UpdateSubscriptionRequestRequestTypeDef = TypedDict(
+    "UpdateSubscriptionRequestRequestTypeDef",
+    {
+        "AutoRenew": AutoRenewType,
+    },
+    total=False,
+)
